<?php
/**
 * RT main class
 * 
 * @package Wordpress_RT
 * @author CH Foo
 * @copyright 2011 rt.feedgeorge.com
 * @access public
 */

class WP_RT {
    
	//private $fgmarkercount = 0;
	private $rt_options = null;
	
    public function __construct() {
       global $rt_admin, $rt_ajax, $rt_layer;
       
	    $this->init();
		
        add_action( 'init', array( &$this, 'init' ) );
		
        add_action( 'wp', Array( &$this, 'load_script' ) );
        add_action( 'wp_head', Array( &$this, 'load_head' ) );
		
		add_action('wp_ajax_exportpoi', Array(&$rt_layer,'exportPoi'));
        add_action('wp_ajax_nopriv_exportpoi', Array(&$rt_layer,'exportPoi'));
		
		add_action('wp_ajax_update_layer', Array(&$rt_admin,'update_layer'));
        add_action('wp_ajax_nopriv_update_layer', Array(&$rt_admin,'update_layer'));
        
		add_action('post_edit_form_tag',  Array( &$this,'update_edit_form')); 
		
        add_action( 'admin_head', array( &$rt_admin, 'admin_head' ) );
		add_action( 'admin_enqueue_scripts', array( &$rt_admin, 'load_script' ) );
		
		add_filter( 'the_content', array( &$this, 'the_content' ) );
		add_filter( 'the_title', array( &$this, 'the_title' ) );
        
		//Register widgets
		add_action('widgets_init', Array(&$this,'register_widgets'));  
        
    }
    
    function load_head() {
        
		$front_geomap['latitude'] = (empty($this->rt_options['front_map_latitude']))? RT_MAP_LAT : $this->rt_options['front_map_latitude'] ;
		$front_geomap['longitude'] = (empty($this->rt_options['front_map_longitude']))? RT_MAP_LNT : $this->rt_options['front_map_longitude']  ;
		
		if (is_single())
			$front_geomap['map_zoom'] = (empty($this->rt_options['post_map_zoom']))? RT_MAP_ZOOM : $this->rt_options['post_map_zoom'];
		else
			$front_geomap['map_zoom'] = (empty($this->rt_options['front_map_zoom']))? RT_MAP_ZOOM : $this->rt_options['front_map_zoom'];
			
		//$front_geomap['marker_icon'] = $this->get_marker_image(RT_MAP_MARKER);
		$front_geomap['dir'] = RT_REL_URL;
        $front_geomap['home'] = home_url();
		
		
		echo '<script type="text/javascript">var RT_default_map = '.json_encode($front_geomap).';</script>';
	
	
    }
	
	
    public function init() {
        $this->rt_options = get_option("_RT_GEOLOCATION_OPTION");
    }
	
	
	
	public function the_title($title = '') {
		global $post;
		
		if (is_home() && in_the_loop() && $post->post_status == 'publish') {
			
			$geolocation = get_post_meta($post->ID, RT_GEOLOCATION, true);
			
			$latitude = get_post_meta($post->ID, 'geo_latitude',true);
			$longitude = get_post_meta($post->ID, 'geo_longitude',true);
			
			if (empty($latitude) && empty($longitude)) {
				if (is_numeric($geolocation['latitude']) && is_numeric($geolocation['longitude'])) {
					$latitude = $geolocation['latitude'];
					$longitude = $geolocation['longitude'];
					
					//global $fg_admin;
					//$fg_admin->savegeotag($post->ID,$latitude,$longitude);
				}
			}
			
			if (is_numeric($latitude) && is_numeric($longitude) ) {
				
					$address = $geolocation[address];
					$postcode = $geolocation[postcode];
					$town = $geolocation[town];
					
					$location = $address . ' ' .$postcode . ' ' .$town;
					$info = '<div id="fg_map_info"><a class="title" href="'.get_permalink().'">'.$post->post_title.'</a><p>'.$location .'<br/><a href="'.get_permalink().'">Detail</a></p></div>';
					
					//$pointer = '<span class="fg_map_icon" style="background: url('.$this->smallmarker.') top center no-repeat;"></span>';
					$pointer = '<span class="fg_map_icon"><img src="'.$this->get_marker_image(FG_MAP_MARKER).'" /></span>';
					
					$place = json_encode(array($post->post_title,$latitude,$longitude," ",$info));
					$place_str = 'geoplace.push('.$place.');';
				
			}
			
			
			$newtitle = '<script>'.$place_str.$kml_str.'</script>';
			$title = $pointer . $title . $newtitle;
			
		}
		
		return $title;
	}	
	
	
	public function the_content($content = '') {
		global $post;
		$showmap = false;
		
		if (!is_feed() && is_single()) {
				//$new_content = apply_filters( 'fgeorge_thecontent', $new_content );
			 $latitude = get_post_meta($post->ID, 'geo_latitude',true);
			$longitude = get_post_meta($post->ID, 'geo_longitude',true);
			
			if (is_numeric($latitude) && is_numeric($longitude) ) {
				$geolocation = get_post_meta($post->ID, RT_GEOLOCATION, true);
				
				if (empty($this->rt_options['post_map_height']))
					$this->rt_options['post_map_height'] = RT_MAP_HEIGHT;
				
				if (empty($this->rt_options['post_map_width']))
					$width = '100%';
				else
					$width = $this->rt_options['post_map_width'] . 'px';
				
				
				$address = $geolocation['address'];
				$city = $geolocation['city'];
				$zoom = $geolocation['zoom'];
				$maptype = $geolocation['maptype'];
				$use_custom_zoom = $geolocation['use_custom_zoom'];
				
				$rtlocation = 'var postlocation = ' .json_encode(Array('postlat'=>$latitude, 'postlng'=>$longitude, 'postzoom'=>$zoom,'postmaptype'=>$maptype,'usecustom'=>$use_custom_zoom)).';';
			
				$new_content .= '
				<div class="rt_post_location">'.$address . ', ' . $city . '</div>
				<div class="rt_post_map" id="geo_postmap_' . $post->ID . '" style="width:'.$width.'; height: '.$this->rt_options['post_map_height'].'px"></div>
				<script>
					'.$rtlocation.'
					var fgkmlfile ="'.$fgkmllink.'";
					fgeo_post_map.init('.$post->ID.',"'.$post->post_title.'")
				</script>
				';
			}

		}
			
		$content = $content . $new_content;
		
		return $content;
	}
	
	
	function register_widgets() {
		register_widget('RTGeoMapWidget');
	}
	
	
	public function getPlaces($place = '') {
		global $wpdb;
		$prefix = $wpdb->prefix;
		
		$sql = 'SELECT meta_value FROM `'.$prefix.'postmeta` WHERE `meta_key` = "geo_city" group by `meta_value`';
		$myrows = $wpdb->get_results( $sql );
		
		return $myrows;
	}
	
	
	public function build_nav_menus() {
		
		global $current_page;
		global $wp_query;
		if ( is_page() || is_attachment() || $wp_query->is_posts_page )
			$current_page = $wp_query->get_queried_object_id();
		$places = $this->getPlaces();
		$pages = get_pages(Array('sort_column'=>'menu_order'));
		$menu = '<li '.(( is_front_page() && !is_paged() )?'class="current_page_item"':'').' ><a href="'.esc_url( home_url( '/' ) ).'">Home</a></li>';
		
		foreach($pages as $page) {
			
			$class = 'page_item';
			
			if ( $page->ID == $current_page )
				$class = 'current_page_item';
			
			$menu .= '<li class="'.$class.'"><a href="'.get_permalink($page->ID).'">'.$page->post_title .'</a>';
			$sub = '';
			
			
			if ($page->post_title == 'Places') {
				foreach($places as $place) {
					$sub .= '<li><a href="'.get_permalink($page->ID).'?place='.$place->meta_value.'">'.$place->meta_value.'</a></li>';
				}
				$menu .= '<ul class="children">'.$sub.'</ul>';
			}
			
			$menu .= '</li>';
		}
		$menu = '<div class="menu"><ul>'.$menu.'</ul></div>';
		
		return $menu;
	}
	
	
	public function get_map($height = 300) {

		$this->fgshowmap = true;
		
		if (empty($this->rt_options['front_map_height']))
			$this->rt_options['front_map_height'] = RT_MAP_HEIGHT;
				
		if (empty($this->rt_options['front_map_width']))
			$width = '100%';
		else
			$width = $this->rt_options['front_map_width'] . 'px';
		
		echo '<div id="rt_topmap" style="width: '.$width.'">';
		echo '<div id="rtmap" style="width:'.$width.'; height:'.$this->rt_options['front_map_height'].'px">Loading ... </div>';
		include(RT_THEMES_DIR . '/embed_form_f.php');
		echo '</div>';
		
		
	}
	
	
    
    public function init_plugin() {
		rt_install();
    }
    
    public function kill_plugin() {
		//rt_uninstall();
    }
	
	public function uninstall_plugin() {
		rt_uninstall();
	}
    
    public function load_script() {
        
		
		//wp_enqueue_style('rt_css', RT_CSS_URL.'/RT_style.css');
		wp_register_style( 'custom_rt_css', RT_REL_URL . '/themes/rt_styles.css', false, '1.0.0' );
        wp_enqueue_style( 'custom_rt_css' );
		 
		wp_enqueue_script('jquery');
		wp_enqueue_script('GoogleMaps','http://maps.google.com/maps/api/js?sensor=false');
	    
		
		//Load Thickbox
		wp_enqueue_style('thickbox');
        wp_enqueue_script('thickbox');

		//if (is_home() ||is_single())
	   wp_enqueue_script('RT_map_script1', RT_JS_URL . '/front_map.js');
			
	
    }
	
	function update_edit_form() {  
		echo ' enctype="multipart/form-data"';  
	} 
	
	
	public function get_marker_image($filename) {
        $upload = wp_upload_dir();
        
        $default_marker = FG_IMG_URL . '/'.$filename;
        $user_marker = $upload['baseurl'] .'/wp-feedgeorge/'. $filename;
        
        if (is_readable($user_marker)) {
            $marker = $user_marker;
        }
        else
            $marker = $default_marker;
        
        return $marker;
    }
	
	public function get_options() {
        return $this->rt_options;
    }
    
}
?>